@@ -736,6 +736,13 @@ class NoCommunity(Exception):
     def __init__(*args, **kwargs):
         Exception.__init__(*args, **kwargs)
 
+class NoBubble(Exception):
+    """
+    Raised when you try to make an action but no bubble pr bubble components was selected.
+    """
+    def __init__(*args, **kwargs):
+        Exception.__init__(*args, **kwargs)
+
 class CommunityNotFound(Exception):
     """
     Raised when you search for a community but nothing is found.
