@@ -2,8 +2,6 @@ import json
 
 from functools import reduce
 from base64 import b64decode
-from typing import BinaryIO
-from zipfile import ZipFile
 
 
 def generate_device_info() -> dict:
@@ -12,12 +10,12 @@ def generate_device_info() -> dict:
         "user_agent": "Dalvik/2.1.0 (Linux; U; Android 5.1.1; SM-G973N Build/beyond1qlteue-user 5; com.narvii.amino.master/3.4.33562)"
     }
 
-def chat_bubble_file(image_path: str, out_path: str = "./", name: str = "Custom Bubble", allowed_slots: list = None,
-                              content_insest_bottom: int = 23, content_insest_right: int = 32, content_insest_top: int = 17, content_insest_left: int = 42,
-                              cover_image_url: str = None, zoom_point_in: int = 57, zoom_point_out: int = 39, text_color: str = "#643573", link_color: str = "#e065ff",
-                              templateId: str = "71b41f1a-4c09-4e07-ac9e-18ef9bbbe65f", prewiew_background_url: str = None, bubbleId: str = None) -> BinaryIO:
+def chat_bubble_config(image_path: str, name: str = "Custom Bubble", allowed_slots: list = None,
+        content_insest_bottom: int = 23, content_insest_right: int = 32, content_insest_top: int = 17, content_insest_left: int = 42,
+        cover_image_url: str = None, zoom_point_in: int = 57, zoom_point_out: int = 39, text_color: str = "#643573", link_color: str = "#e065ff",
+        templateId: str = "71b41f1a-4c09-4e07-ac9e-18ef9bbbe65f", prewiew_background_url: str = None, bubbleId: str = None) -> dict: # Fix this config, pls
     """
-    Generate chat bubble from template.
+    Generate config to chat bubble.
 
     **Parameters**
         - **image_path** : Path to bubble image.
@@ -66,7 +64,7 @@ def chat_bubble_file(image_path: str, out_path: str = "./", name: str = "Custom
         "linkColor": link_color,
         "templateId": templateId,
         "slots": None,
-        "backgroundPath": "bg.png",
+        "backgroundPath": image_path,
         "id": bubbleId,
         "color": text_color,
         "previewBackgroundUrl": "http://cb1.narvii.com/images/6846/65d316d6529153c76e2b8e8756739355f2720764_00.png"
@@ -81,12 +79,7 @@ def chat_bubble_file(image_path: str, out_path: str = "./", name: str = "Custom
     if cover_image_url:
         config["coverImage"] = cover_image_url
 
-    with ZipFile(f"{out_path}{name}.zip", 'w') as zip_file:
-        zip_file.writestr("config.json", json.dumps(config))
-        zip_file.write(image_path, "bg.png")
-
-    return f"{out_path}{name}.zip"
-
+    return config
 
 # okok says: please use return annotations :(( https://www.python.org/dev/peps/pep-3107/#return-values
 
