@@ -61,14 +61,14 @@ class SocketHandler:
 
             time.sleep(5)
 
-    def on_open(self):
+    def on_open(self, ws):
         if self.debug:
             print("[socket][on_open] Socket Opened")
-        self.send("CONNECT\naccept-version:1.0,1.1,2.0\n\n\x00\n")
 
-    def on_close(self):
+    def on_close(self, ws, status, data):
         if self.debug:
             print("[socket][on_close] Socket Closed")
+            print(f"Status: {status}; Data: {data}")
 
         self.active = False
 
@@ -76,13 +76,13 @@ class SocketHandler:
             if self.debug:
                 print("[socket][on_close] reconnect is True, Opening Socket")
 
-    def on_ping(self, data):
+    def on_ping(self, ws, data):
         if self.debug:
             print("[socket][on_ping] Socket Pinged")
 
         contextlib.suppress(self.socket.sock.pong(data))
 
-    def handle_message(self, data):
+    def handle_message(self, ws, data):
         self.client.handle_socket_message(data)
         return
 
@@ -95,17 +95,15 @@ class SocketHandler:
     def get_websocket_url(self):
         headers = {"cookie": f"sid={self.client.sid};"}
         response = requests.get(f"{self.client.web_api}/chat/web-socket-url", headers=headers)
-        if response.status_code != 200:
-            raise Exception(response.json())
-        else:
-            return response.json()["result"]["url"]
+        if response.status_code != 200: raise Exception(response.json())
+        else: return response.json()["result"]["url"]
 
     def start(self):
         if self.debug:
             print(f"[socket][start] Starting Socket")
         
         if not self.socket_stoped:
-            Warning("[socket][start] Old socket is not closed.")
+            Warning("[socket][start] Old socket dont closed.")
 
         self.socket = websocket.WebSocketApp(
             self.get_websocket_url(),
